/*
 * Copyright 2016-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.http.netconfcentral.org.ns.siltest3.rev20110916.siltest3;

import com.google.common.base.MoreObjects;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import org.onosproject.yang.gen.v1.http.netconfcentral.org.ns.siltest3.rev20110916.siltest3.u.UuUnion;
import org.onosproject.yang.gen.v1.http.netconfcentral.org.ns.siltest3.rev20110916.siltest3.u.UxUnion;
import org.onosproject.yangutils.translator.tojava.AugmentedInfo;

/**
 * Represents the builder implementation of u.
 */
public class UBuilder implements U.UBuilder {

    private UxUnion ux;
    private long uy;
    private long uz;
    private UuUnion uu;

    @Override
    public UxUnion ux() {
        return ux;
    }

    @Override
    public long uy() {
        return uy;
    }

    @Override
    public long uz() {
        return uz;
    }

    @Override
    public UuUnion uu() {
        return uu;
    }

    @Override
    public UBuilder ux(UxUnion ux) {
        this.ux = ux;
        return this;
    }

    @Override
    public UBuilder uy(long uy) {
        this.uy = uy;
        return this;
    }

    @Override
    public UBuilder uz(long uz) {
        this.uz = uz;
        return this;
    }

    @Override
    public UBuilder uu(UuUnion uu) {
        this.uu = uu;
        return this;
    }

    @Override
    public U build() {
        return new UImpl(this);
    }

    /**
     * Creates an instance of ubuilder.
     */
    public UBuilder() {
    }


    /**
     * Represents the implementation of u.
     */
    public final class UImpl implements U {

        private List<AugmentedInfo> augmentedInfoList = new ArrayList<>();
        private UxUnion ux;
        private long uy;
        private long uz;
        private UuUnion uu;

        @Override
        public UxUnion ux() {
            return ux;
        }

        @Override
        public long uy() {
            return uy;
        }

        @Override
        public long uz() {
            return uz;
        }

        @Override
        public UuUnion uu() {
            return uu;
        }

        @Override
        public int hashCode() {
            return Objects.hash(ux, uy, uz, uu);
        }

        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (obj instanceof UImpl) {
                UImpl other = (UImpl) obj;
                return
                     Objects.equals(ux, other.ux) &&
                     Objects.equals(uy, other.uy) &&
                     Objects.equals(uz, other.uz) &&
                     Objects.equals(uu, other.uu);
            }
            return false;
        }

        @Override
        public String toString() {
            return MoreObjects.toStringHelper(getClass())
                .add("ux", ux)
                .add("uy", uy)
                .add("uz", uz)
                .add("uu", uu)
                .toString();
        }

        /**
         * Creates an instance of uImpl.
         *
         * @param builderObject builder object of u
         */
        public UImpl(UBuilder builderObject) {
            this.ux = builderObject.ux();
            this.uy = builderObject.uy();
            this.uz = builderObject.uz();
            this.uu = builderObject.uu();
        }

        @Override
        public void addAugmentation(AugmentedInfo value) {
            getAugmentedInfoList().add(value);
        }

        @Override
        public List<AugmentedInfo> getAugmentedInfoList() {
            return augmentedInfoList;
        }

        @Override
        public void removeAugmentation() {
            getAugmentedInfoList().clear();
        }
    }
}