/*
 * Copyright 2016-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.http.netconfcentral.org.ns.siltest3.rev20110916.siltest3.u;

import java.util.Objects;
import com.google.common.base.MoreObjects;

/**
 * Represents the implementation of uuUnion.
 */
public final class UuUnion {

    private int int32;
    private short uint8;
    private boolean yangAutoPrefixBoolean;

    /**
     * Creates an instance of uuUnion.
     */
    private UuUnion() {
    }

    /**
     * Creates an instance of uuUnionForTypeInt32.
     *
     * @param value value of uuUnionForTypeInt32
     */
    public UuUnion(int value) {
        this.int32 = value;
    }

    /**
     * Creates an instance of uuUnionForTypeUint8.
     *
     * @param value value of uuUnionForTypeUint8
     */
    public UuUnion(short value) {
        this.uint8 = value;
    }

    /**
     * Creates an instance of uuUnionForTypeBoolean.
     *
     * @param value value of uuUnionForTypeBoolean
     */
    public UuUnion(boolean value) {
        this.boolean = value;
    }

    /**
     * Returns the object of uuUnionForTypeInt32.
     *
     * @param value value of uuUnionForTypeInt32
     * @return Object of uuUnionForTypeInt32
     */
    public static UuUnion of(int value) {
        return new UuUnion(value);
    }

    /**
     * Returns the object of uuUnionForTypeUint8.
     *
     * @param value value of uuUnionForTypeUint8
     * @return Object of uuUnionForTypeUint8
     */
    public static UuUnion of(short value) {
        return new UuUnion(value);
    }

    /**
     * Returns the object of uuUnionForTypeBoolean.
     *
     * @param value value of uuUnionForTypeBoolean
     * @return Object of uuUnionForTypeBoolean
     */
    public static UuUnion of(boolean value) {
        return new UuUnion(value);
    }

    /**
     * Returns the attribute int32.
     *
     * @return value of int32
     */
    public int int32() {
        return int32;
    }

    /**
     * Returns the attribute uint8.
     *
     * @return value of uint8
     */
    public short uint8() {
        return uint8;
    }

    /**
     * Returns the attribute yangAutoPrefixBoolean.
     *
     * @return value of yangAutoPrefixBoolean
     */
    public boolean boolean() {
        return boolean;
    }

    @Override
    public int hashCode() {
        return Objects.hash(int32, uint8, boolean);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof UuUnion) {
            UuUnion other = (UuUnion) obj;
            return
                 Objects.equals(int32, other.int32) &&
                 Objects.equals(uint8, other.uint8) &&
                 Objects.equals(boolean, other.boolean);
        }
        return false;
    }

    @Override
    public String toString() {
        return MoreObjects.toStringHelper(getClass())
            .omitNullValues()
            .add("int32", int32)
            .add("uint8", uint8)
            .add("boolean", boolean)
            .toString();
    }

    /**
     * Returns the object of uuUnion fromString input String.
     *
     * @param valInString input String
     * @return Object of uuUnion
     */
    public static UuUnion fromString(String valInString) {
        try {
            int tmpVal = Integer.parseInt(valInString);
            return of(tmpVal);
        } catch (Exception e) {
        }
        try {
            short tmpVal = Short.parseShort(valInString);
            return of(tmpVal);
        } catch (Exception e) {
        }
        try {
            boolean tmpVal = Boolean.parseBoolean(valInString);
            return of(tmpVal);
        } catch (Exception e) {
        }
        return null;
    }
}
