/*
 * Copyright 2016-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.http.netconfcentral.org.ns.siltest3.rev20110916.siltest3.u;

import java.util.Objects;
import com.google.common.base.MoreObjects;

/**
 * Represents the implementation of uxUnion.
 */
public final class UxUnion {

    private long uint32;
    private String string;

    /**
     * Creates an instance of uxUnion.
     */
    private UxUnion() {
    }

    /**
     * Creates an instance of uxUnionForTypeUint32.
     *
     * @param value value of uxUnionForTypeUint32
     */
    public UxUnion(long value) {
        this.uint32 = value;
    }

    /**
     * Creates an instance of uxUnionForTypeString.
     *
     * @param value value of uxUnionForTypeString
     */
    public UxUnion(String value) {
        this.string = value;
    }

    /**
     * Returns the object of uxUnionForTypeUint32.
     *
     * @param value value of uxUnionForTypeUint32
     * @return Object of uxUnionForTypeUint32
     */
    public static UxUnion of(long value) {
        return new UxUnion(value);
    }

    /**
     * Returns the object of uxUnionForTypeString.
     *
     * @param value value of uxUnionForTypeString
     * @return Object of uxUnionForTypeString
     */
    public static UxUnion of(String value) {
        return new UxUnion(value);
    }

    /**
     * Returns the attribute uint32.
     *
     * @return value of uint32
     */
    public long uint32() {
        return uint32;
    }

    /**
     * Returns the attribute string.
     *
     * @return value of string
     */
    public String string() {
        return string;
    }

    @Override
    public int hashCode() {
        return Objects.hash(uint32, string);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof UxUnion) {
            UxUnion other = (UxUnion) obj;
            return
                 Objects.equals(uint32, other.uint32) &&
                 Objects.equals(string, other.string);
        }
        return false;
    }

    @Override
    public String toString() {
        return MoreObjects.toStringHelper(getClass())
            .omitNullValues()
            .add("uint32", uint32)
            .add("string", string)
            .toString();
    }

    /**
     * Returns the object of uxUnion fromString input String.
     *
     * @param valInString input String
     * @return Object of uxUnion
     */
    public static UxUnion fromString(String valInString) {
        try {
            long tmpVal = Long.parseLong(valInString);
            return of(tmpVal);
        } catch (Exception e) {
        }
        try {
            String tmpVal = (valInString);
            return of(tmpVal);
        } catch (Exception e) {
        }
        return null;
    }
}
